/** File Header		***************************************************************************
*** NAME: 				Core
*** EXTENSION: 			C
*** DESCRIPTION: 		Core Logic general functions.
*** WRITTEN BY: 		Tal Gil
*** UPDATED LAST ON: 	11 JAN 1999
*** VERSION: 1.0	***************************************************************************/

#include "DMA.h"
#include "Core.h"
#include "io.h"
#include "counters.h"

UINT GT_INTERNAL_REG_BASE = 0x14000000; // Must be declared external in each file it is being used

/** Function Header ***************************************************************************
*** DESCRIPTION:		Writes data to an internal GT register
*** WRITTEN BY: 		Tal Gil
*** UPDATED LAST ON: 	11 JAN 1999
*** VERSION: 1.0    ***************************************************************************/

void write_internal_reg(UINT offset,UINT data)
{ 
 	*((UINT *)(NONE_CACHEABLE | (GT_INTERNAL_REG_BASE + offset))) = GTREG(data);
}

void write_internal(UINT offset,UINT* data)
{  // printf("write %08x to %08x\n",GTREG(*data),offset);
 	*((UINT *)(NONE_CACHEABLE | (GT_INTERNAL_REG_BASE + offset))) = GTREG(*data);
}

/** Function Header ***************************************************************************
*** DESCRIPTION:		Reads data from an internal GT register
*** WRITTEN BY: 		Tal Gil
*** UPDATED LAST ON:	11 JAN 1999
*** VERSION: 1.0    ***************************************************************************/

UINT read_internal_reg(UINT offset)
{
  	UINT tmp;
  	tmp = *((UINT *)(NONE_CACHEABLE | (GT_INTERNAL_REG_BASE + offset)));
  	return GTREG(tmp);
}

UINT read_internal(UINT offset, UINT *data)
{

  	UINT tmp;
//    printf(" read from %08x to %08x \n",offset,*data);
  	tmp = *((UINT *)(NONE_CACHEABLE | (GT_INTERNAL_REG_BASE + offset)));
    *data =  GTREG(tmp);
  	return GTREG(tmp);
}

/** Function Header ***************************************************************************
*** DESCRIPTION:		Write data to an internal GT register on another board
*** WRITTEN BY: 		Tal Gil
*** UPDATED LAST ON:	20 July 1999
*** VERSION: 1.0    ***************************************************************************/

void slave_write_internal_reg(UINT offset,UINT data)
{
    UINT pci_mem0_base_address,remap_register_saved_data;
    pci_mem0_base_address = read_internal_reg(PCI_0MEMORY0_LOW_DECODE_ADDRESS);
    pci_mem0_base_address = pci_mem0_base_address << 21;
    remap_register_saved_data = read_internal_reg(PCI_0MEMORY0_ADDRESS_REMAP);
    // Remap pci mem0 to hit the slave`s internal registers.
    write_internal_reg(PCI_0MEMORY0_ADDRESS_REMAP,0xa0);
    write_word(pci_mem0_base_address + offset,data);
    write_internal_reg(PCI_0MEMORY0_ADDRESS_REMAP,remap_register_saved_data);
}


/** Function Header ***************************************************************************
*** DESCRIPTION:		Read data from an internal GT register on another board
*** WRITTEN BY: 		Tal Gil
*** UPDATED LAST ON:	20 July 1999
*** VERSION: 1.0    ***************************************************************************/

UINT slave_read_internal_reg(UINT offset)
{
    UINT pci_mem0_base_address,remap_register_saved_data,data;
    pci_mem0_base_address = read_internal_reg(PCI_0MEMORY0_LOW_DECODE_ADDRESS);
    pci_mem0_base_address = pci_mem0_base_address << 21;
    remap_register_saved_data = read_internal_reg(PCI_0MEMORY0_ADDRESS_REMAP);
    // Remap pci mem0 to hit the slave`s internal registers.
    write_internal_reg(PCI_0MEMORY0_ADDRESS_REMAP,0xa0);
//    data = read_word(pci_mem0_base_address + offset);
    read_word(pci_mem0_base_address + offset,&data);
    write_internal_reg(PCI_0MEMORY0_ADDRESS_REMAP,remap_register_saved_data);
    return data;
}

/** Function Header ***************************************************************************
*** DESCRIPTION:		Writes 4 bytes to memory.
*** WRITTEN BY: 		Tal Gil
*** UPDATED LAST ON:	11 JAN 1999
*** VERSION: 1.0    ***************************************************************************/

void write_word(UINT addr,UINT data)
{ 
  	*((UINT *)(addr | NONE_CACHEABLE)) = GTREG(data);
}

/** Function Header ***************************************************************************
*** DESCRIPTION:		Writes 2 bytes to memory.
*** WRITTEN BY: 		Tal Gil
*** UPDATED LAST ON:	11 JAN 1999
*** VERSION: 1.0    ***************************************************************************/

void write_short(UINT addr,unsigned short data)
{ 
    *((unsigned short *)(addr | NONE_CACHEABLE)) = ((data << 8) | (data >> 8));
}

/** Function Header ***************************************************************************
*** DESCRIPTION:		Writes 2 bytes to memory.
*** WRITTEN BY: 		Tal Gil
*** UPDATED LAST ON:	11 JAN 1999
*** VERSION: 1.0    ***************************************************************************/

USHORT read_short(UINT addr)
{ 
  	USHORT tmp;
  	tmp = *((USHORT*)(NONE_CACHEABLE | addr));
  	return ((tmp << 8) | (tmp >> 8));
}
 /** Function Header ***************************************************************************
*** DESCRIPTION:		Writes to cachable memory .
*** WRITTEN BY: 		Tal Gil
*** UPDATED LAST ON:	11 JAN 1999
*** VERSION: 1.0    ***************************************************************************/

void write_word_cachable(UINT addr,UINT data)
{ 
 	*((UINT *)(addr | CACHEABLE)) = GTREG(data);
}

/** Function Header ***************************************************************************
*** DESCRIPTION:		Reads from memory .
*** WRITTEN BY: 		Tal Gil
*** UPDATED LAST ON:	11 JAN 1999
*** VERSION: 1.0    ***************************************************************************/

UINT read_word(UINT addr,UINT* data)
{
  	UINT tmp;
  	tmp = *(UINT *)(addr | NONE_CACHEABLE);
    *data = GTREG(tmp);

 	return (*data);
}

/** Function Header ***************************************************************************
*** DESCRIPTION:		Reads from cachable memory.
*** WRITTEN BY: 		Tal Gil
*** UPDATED LAST ON:	11 JAN 1999
*** VERSION: 1.0    ***************************************************************************/

UINT read_word_cachable	(UINT addr)
{
  	UINT tmp;
  	tmp = *((UINT *)(addr | CACHEABLE));
  	return GTREG(tmp);
}
   	
/** Function Header ***************************************************************************
*** DESCRIPTION:		Writes to a PCI config register.
*** WRITTEN BY: 		Tal Gil
*** UPDATED LAST ON:	26 JAN 1999
*** VERSION: 1.0    ***************************************************************************/

void write_config_reg(Boolean bus,UINT reg_offset,UINT slot_number,UINT data)
{
   	UINT   DataFor_cf8;
   	slot_number = slot_number << 11;
   	DataFor_cf8 = (reg_offset + slot_number)|0x80000000;
   	if(bus) 
	{
		*((UINT *)(NONE_CACHEABLE |( GT_INTERNAL_REG_BASE + PCI_1CONFIGURATION_ADDRESS))) = GTREG(DataFor_cf8);
   		if(slot_number == THIS_SLOT)
   		{
   			*((UINT *)(NONE_CACHEABLE |( GT_INTERNAL_REG_BASE + PCI_1CONFIGURATION_DATA_VIRTUAL_REGISTER))) = GTREG(data);
   		}
   		else
   		{
   			*((UINT *)(NONE_CACHEABLE |( GT_INTERNAL_REG_BASE + PCI_1CONFIGURATION_DATA_VIRTUAL_REGISTER))) = data;
   		}
    }
    else 
	{
		*((UINT *)(NONE_CACHEABLE |( GT_INTERNAL_REG_BASE + PCI_0CONFIGURATION_ADDRESS))) = GTREG(DataFor_cf8);
   		if(slot_number == THIS_SLOT)
   		{
   			*((UINT *)(NONE_CACHEABLE |( GT_INTERNAL_REG_BASE + PCI_0CONFIGURATION_DATA_VIRTUAL_REGISTER))) = GTREG(data);
   		}
   		else
   		{
   			*((UINT *)(NONE_CACHEABLE |( GT_INTERNAL_REG_BASE + PCI_0CONFIGURATION_DATA_VIRTUAL_REGISTER))) = data;
   		}
    }
}

/** Function Header ***************************************************************************
*** DESCRIPTION:		Reads a PCI config register.
*** WRITTEN BY: 		Tal Gil
*** UPDATED LAST ON:	26 JAN 1999
*** VERSION: 1.0    ***************************************************************************/

UINT read_config_reg(Boolean bus,UINT reg_offset,UINT slot_number)
{
    UINT DataFor_cf8;
   	UINT data;
   	
   	slot_number = slot_number << 11;
   	DataFor_cf8 = (reg_offset + slot_number)|0x80000000;
    
    if(bus) 
	{
   		*((UINT *)(NONE_CACHEABLE |(GT_INTERNAL_REG_BASE + PCI_1CONFIGURATION_ADDRESS))) = GTREG(DataFor_cf8);
   		data = *((UINT *)(NONE_CACHEABLE |(GT_INTERNAL_REG_BASE + PCI_1CONFIGURATION_DATA_VIRTUAL_REGISTER)));
    }
    else 
	{
   		*((UINT *)(NONE_CACHEABLE |(GT_INTERNAL_REG_BASE + PCI_0CONFIGURATION_ADDRESS))) = GTREG(DataFor_cf8);
   		data = *((UINT *)(NONE_CACHEABLE |(GT_INTERNAL_REG_BASE + PCI_0CONFIGURATION_DATA_VIRTUAL_REGISTER)));
    }
    if(slot_number == THIS_SLOT)
   	{
    	return GTREG(data);
    }
    else
    {
    	return data;
    }
}

/** Function Header ***************************************************************************
*** DESCRIPTION:		Initializes a Device`s bank parameters.
*** 					To keep an old value place DEFAULT (defined as -1) for the parameter, 
***						initialize options this way: options = _8BIT | DMA_FLY_BY | ....
*** WRITTEN BY: 		Tal Gil
*** UPDATED LAST ON:	11 JAN 1999
*** VERSION: 1.0    ***************************************************************************/

void modify_device_parameters(UINT bank,int TurnOff,int AccToFirst,int AccToNext,int ALEtoWr,int WrActive,
							  int WrHigh,UINT options)
{
  	UINT data,temp,old_value;
  	if(bank > 3) 		return;
  	if((TurnOff > 0x7) || (AccToFirst > 0xf) || (AccToNext > 0xf) || (ALEtoWr > 0x7) || (WrActive > 0x7)
  		|| (WrHigh > 0x7)) return;
  		
  	old_value = read_internal_reg(DEVICE_BANK0PARAMETERS + bank*4);
  	if(TurnOff < 0) 	TurnOff 	= old_value & 0x00000007;
  	else				TurnOff 	= TurnOff;
  	
  	if(AccToFirst < 0) 	AccToFirst 	= old_value & 0x00000078;
  	else				AccToFirst 	= AccToFirst << 3;
  	
  	if(AccToNext < 0) 	AccToNext  	= old_value & 0x00000780;
  	else				AccToNext  	= AccToNext << 7;
  	
  	if(ALEtoWr < 0) 	ALEtoWr  	= old_value & 0x00003800;
  	else				ALEtoWr  	= ALEtoWr << 11;
  	
  	if(WrActive < 0) 	WrActive  	= old_value & 0x0001c000;
  	else				WrActive  	= WrActive << 14;
  	
  	if(WrHigh < 0) 		WrHigh  	= old_value & 0x000e0000;
  	else				WrHigh  	= WrHigh << 17;
  	
  	data = TurnOff | AccToFirst | AccToNext | ALEtoWr | WrActive | WrHigh | options; 
  	
  	write_internal_reg(DEVICE_BANK0PARAMETERS + bank*4 , data);
}

/** Function Header ***************************************************************************
*** DESCRIPTION:		Writes to the PCI`s timeout and retry register.
*** WRITTEN BY: 		Tal Gil
*** UPDATED LAST ON:	11 JAN 1999
*** VERSION: 1.0    ***************************************************************************/

void write_pci_timeout_and_retry(Boolean bus,UINT timeout0,UINT timeout1,UINT retry)
{
  	UINT addr,data = 0;
  	data = (timeout0 & 0xff) + ((timeout1 & 0xff)<<8) + ((retry & 0xff)<<16);
  	if ( bus ) 	addr = PCI_1TIMEOUT_RETRY;
	else		addr = PCI_0TIMEOUT_RETRY;
  	write_internal_reg(addr,data);
}

/** Function Header ***************************************************************************
*** DESCRIPTION:		Compares the content of the memory region specified with - value.
*** WRITTEN BY: 		Tal Gil
*** UPDATED LAST ON:	24 JAN 1999
*** VERSION: 1.0    ***************************************************************************/

Boolean compare_mem(UINT start_addr,UINT num_of_words,UINT value)
{
	UINT counter,temp;
	for(counter = 0 ; counter < num_of_words ; counter++)
	{
		if(read_word(start_addr + counter*4,&temp) != value) 
		{
#ifdef debug_64115
    		*(UINT *)0xb2000000 = 0xeeeeeeee;
    		printf("DEBUG: error in compare_mem, exiting.\n");
    		printf("Value: %x Data read:%x\n",value,read_word(start_addr + counter*4,&temp));
    		exit(0);
#endif
			return false;
		}
	}
	return true;
}

/** Function Header ***************************************************************************
*** DESCRIPTION:		Writes a block of data to memory and checks if it was written correctly.
*** WRITTEN BY: 		Tal Gil
*** UPDATED LAST ON:	31 JAN 1999
*** VERSION: 1.0    ***************************************************************************/

Boolean	write_block_and_check(UINT base_addr,UINT num_of_words,UINT data)
{
	UINT	counter;
	for(counter = 0 ; counter < num_of_words ; counter++)
	{
		write_word(base_addr + counter*4,data);
	}
	return (compare_mem(base_addr,num_of_words,data));
}

/** Function Header ***************************************************************************
*** DESCRIPTION:		Writes a block of data to memory.
*** WRITTEN BY: 		Tal Gil
*** UPDATED LAST ON:	31 JAN 1999
*** VERSION: 1.0    ***************************************************************************/

void write_block(UINT base_addr,UINT num_of_words,UINT data)
{
	UINT	counter;
	for(counter = 0 ; counter < num_of_words ; counter++)
	{
		write_word(base_addr + counter*4,data);
	}
}
		
/** Function Header ***************************************************************************
*** DESCRIPTION:		For each register needed to be saved: write its offset to the GT_struct,
***						the last value must be -1 !!!
*** WRITTEN BY: 		Tal Gil
*** UPDATED LAST ON:	1 FEB 1999
*** VERSION: 1.0    ***************************************************************************/

void save_GT_state(GT_STRUCT * gt_struct_pointer)
{
	UINT counter;
	for(counter = 0 ; (counter < 100) & (gt_struct_pointer->reg_num[counter] != -1) ; counter++)
	{
		gt_struct_pointer->reg_data[counter] = read_internal_reg(gt_struct_pointer->reg_num[counter]);
	}
}

/** Function Header ***************************************************************************
*** DESCRIPTION:		With this function you must use the same GT_struct you used with save_GT_state.
*** WRITTEN BY: 		Tal Gil
*** UPDATED LAST ON:	1 FEB 1999
*** VERSION: 1.0    ***************************************************************************/

void restore_GT_state(GT_STRUCT * gt_struct_pointer)
{
	UINT counter;
	for(counter = 0 ; (counter < 100) & (gt_struct_pointer->reg_num[counter] != -1) ; counter++)
	{
		write_internal_reg(gt_struct_pointer->reg_num[counter],gt_struct_pointer->reg_data[counter]);
	}
}

/** Function Header ***************************************************************************
*** DESCRIPTION:		Byte write.
*** WRITTEN BY: 		Tal Gil
*** UPDATED LAST ON:	3 FEB 1999
*** VERSION: 1.0    ***************************************************************************/

void write_char(UINT addr,char data)
{
	*((unsigned char *)(addr | NONE_CACHEABLE)) = data;	
}

/** Function Header ***************************************************************************
*** DESCRIPTION:		 Read Byte.
*** WRITTEN BY: 		Tal Gil
*** UPDATED LAST ON:	3 FEB 1999
*** VERSION: 1.0    ***************************************************************************/

unsigned char read_char(UINT addr)
{
	return *((unsigned char *)(addr | NONE_CACHEABLE));
}

/** Function Header ***************************************************************************
*** DESCRIPTION:		 Compares two memory regions byte by byte, if a miss match is detected
***						 the function returns false otherwise true.
*** WRITTEN BY: 		Tal Gil
*** UPDATED LAST ON:	3 FEB 1999
*** VERSION: 1.0    ***************************************************************************/

Boolean	compare_regions(UINT region1_base,UINT region2_base,UINT num_of_bytes)
{
	UINT counter;
    for(counter = 0 ; counter < num_of_bytes ; counter++)
	{
		if( read_char(region1_base + counter) != read_char(region2_base + counter)) 
        {
            
//#ifdef debug_64115
//    		*(UINT *)0xb2000000 = 0xeeeeeeee;
    		printf("DEBUG: error in compare_regions, exiting.\n");
    		printf("Region1 address: %x data: %x\n",region1_base + counter,read_char(region1_base + counter));
            printf("Region2 address: %x data: %x\n",region2_base + counter,read_char(region2_base + counter));
            exit(0);
//#endif
            return false;
        } 
        
	}

    printf("compare of first buffer -  O.K. \n");
	return true;
}

void print_reg_val(UINT address,char *reg_name)
{
    UINT    temp;

    read_internal(address  , (UINT*)&temp);

    printf("reg: %s (%08x) = %08x \n",reg_name,address,temp);
}
