/** File Header		***************************************************************************
*** NAME: 				Core
*** EXTENSION: 			H
*** DESCRIPTION: 		General Core Logic definitions.
*** WRITTEN BY: 		Tal Gil
*** UPDATED LAST ON: 	May 11 1999
*** VERSION: 1.0	***************************************************************************/

#ifndef _CORE_H 
#define _CORE_H

/* Big/Little endian definition	*/

#ifdef LE         	
#define GTREG(X) (X)
#define LONG_GTREG(X) ((l64)(X))
#else             	
#define GTREG(X) (((X)&0xff)<<24)+(((X)&0xff00)<<8)+(((X)&0xff0000)>>8)+(((X)&0xff000000)>>24)
#define LONG_GTREG(X) ((l64)(((X)&0xffULL)<<56)+(((X)&0xff00ULL)<<40)+(((X)&0xff0000ULL)<<24)+(((X)&0xff000000ULL)<<8)+(((X)&0xff00000000ULL)>>8)+(((X)&0xff0000000000ULL)>>24)+(((X)&0xff000000000000ULL)>>40)+(((X)&0xff00000000000000ULL)>>56))
#endif


#define UINT  unsigned int
typedef enum boolean{false,true} Boolean;

#ifndef  __VXWORKS

//typedef unsigned int 	UINT;
typedef unsigned short  USHORT;
typedef unsigned char   UCHAR;
#endif
typedef char*			STRING;

#define NULL				0
#define GT64115ID           0x461111ab
#define GT64120ID           0x462011ab
#define SEC100ID            0x480211ab

#ifndef GT64130
#define NONE_CACHEABLE		0xa0000000
#define CACHEABLE			0x80000000
#endif

#ifdef  GT64130
#define NONE_CACHEABLE		0x00000000
#define CACHEABLE			0x00000000
#endif

#define PCI_BASE_ADDRESS	0x12000000

#define _100MHz             100.0
#define	_75MHz				75.0
#define	_66MHz				66.0
#define	_80MHz				80.0
#define	_50MHz				50.0
#define _33MHz              33.0

/* Device`s parameters definitions */
#define DEFAULT						-1
#define DONT_MODIFY                 -1
#define _8BIT						0x00000000
#define _16BIT						0x00100000
#define _32BIT						0x00200000 
#define _64BIT						0x00300000
#define PARITY_SUPPORT				0x40000000

#if defined(GT64120) || defined(GT64120A) || defined(GT64130)
#define ODD_BANK					0x00800000
#define DMA_FLY_BY					0x00400000
#define FORWARD_DMA_FLY_BY_TO_CS0	0x04000000
#define FORWARD_DMA_FLY_BY_TO_CS1	0x08000000
#define FORWARD_DMA_FLY_BY_TO_CS2	0x10000000
#define FORWARD_DMA_FLY_BY_TO_CS3	0x20000000
#endif

#if defined(GT64120) || defined(GT64120A) || defined(GT64130) || defined(GT64115) || defined(GT96100)
#define 	MASTER_ENABLE			0x02800007
#define		MASTER_DISABLE			0x02800000
#define		SLAVE_DISABLE			0x02800000
#define		SLAVE_ENABLE			0x02800003
#endif

#ifdef GT64111
#define 	MASTER_ENABLE			0x02800004
#define		MASTER_DISABLE			0x02800000
#define		SLAVE_DISABLE			0x02800000
#define		SLAVE_ENABLE			0x02800003
#endif

#define		SLOT0					7
#define		SLOT1					6
#define		SLOT2					8
#define		SLOT3					9
#define		THIS_SLOT				0
#define		BRIDGE					10
#define		PCI_BUS0				0
#define		PCI_BUS1				1

typedef struct GT_struct
{
	int		reg_num[100];
	UINT	reg_data[100];
} GT_STRUCT;

void 		write_internal_reg	(UINT offset,UINT data);
UINT 		read_internal_reg 	(UINT offset);
void        slave_write_internal_reg(UINT offset,UINT data);
UINT        slave_read_internal_reg(UINT offset);
void 		write_word 			(UINT addr,UINT data);            	/* 4 bytes write */
UINT 		read_word			(UINT addr,UINT* data);
void        write_short         (UINT addr,USHORT data);            /* 2 bytes write */
USHORT      read_short          (UINT addr);       
void 		write_char 			(UINT addr,char data);            	/* 1 byte  write */
UCHAR 		read_char			(UINT addr); 
void 		write_word_cachable	(UINT addr,UINT data);
UINT 		read_word_cachable	(UINT addr);  
Boolean		write_word_to_PCI	(UINT addr,UINT data);   			/* 4 bytes write to PCI */
UINT 		read_word_from_PCI	(UINT addr);  
void 		write_config_reg    (Boolean bus,UINT reg_offset,UINT slot_number,UINT data);
UINT 		read_config_reg     (Boolean bus,UINT reg_offset,UINT slot_number);
void 		modify_device_parameters(UINT bank,int TurnOff,int AccToFirst,int AccToNext,int ALEtoWr,int WrActive,
									 int WrHigh,UINT options);
void 		write_pci_timeout_and_retry(Boolean bus,UINT timeout0,UINT timeout1,UINT retry);
Boolean 	compare_mem(UINT start_addr,UINT num_of_words,UINT value);
Boolean		write_block_and_check(UINT base_addr,UINT num_of_words,UINT data);
void		write_block(UINT base_addr,UINT num_of_words,UINT data);
void		save_GT_state(GT_STRUCT * gt_struct_pointer);
void		restore_GT_state(GT_STRUCT * gt_struct_pointer);
Boolean		compare_regions(UINT region1_base,UINT region2_base,UINT num_of_bytes);
UINT		get_bank_base_address(UINT bank);
Boolean		write_64bit(UINT addr,UINT data_high,UINT data_low);
Boolean		read_64bit(UINT addr,UINT * two_words_array);
Boolean		write_64bit_to_pci(UINT addr,UINT data_high,UINT data_low);
Boolean		read_64bit_from_pci(UINT addr,UINT * two_words_array);
//UINT        get_boards_freq(UINT baud_rate,UINT uart_fifo_size);

#endif _CORE_H
