/** File Header		***************************************************************************
*** NAME: 				COUNTERS
*** EXTENSION: 			C
*** DESCRIPTION: 		GT counters/timers functions.
*** WRITTEN BY: 		Tal Gil
*** UPDATED LAST ON: 	6 JAN 1999
*** VERSION: 1.0    ***************************************************************************/

#include "Counters.h"

/** Function Header ***************************************************************************
*** DESCRIPTION:		Starts a counter.
*** WRITTEN BY: 		Tal Gil
*** UPDATED LAST ON: 	11 Mar 1999
*** VERSION: 1.0    ***************************************************************************/

void start_counter(UINT counter_num,UINT counter_value)
{
	UINT command=1;
	UINT value = read_internal_reg(TIMER_COUNTER_CONTROL);
	if ( counter_num > 3 ) return;
    disable_counter_timer(counter_num);
    write_internal_reg((TIMER_COUNTER0 + (4*counter_num)),counter_value);
    command = command << counter_num*2; // Enable the counter
    value = value | command;
    command = command << 1;
    value = value & (0xffffffff - command); // Select counter
    write_internal_reg(TIMER_COUNTER_CONTROL,value);
}

/** Function Header ***************************************************************************
*** DESCRIPTION:		Starts a timer.
*** WRITTEN BY: 		Tal Gil
*** UPDATED LAST ON: 	11 Mar 1999
*** VERSION: 1.0    ***************************************************************************/

void start_timer(UINT timer_num,UINT timer_value)
{
	UINT command=1;
	UINT value = read_internal_reg(TIMER_COUNTER_CONTROL);
	if ( timer_num > 3 ) return;
    disable_counter_timer(timer_num);
    write_internal_reg((TIMER_COUNTER0 + (4*timer_num)),timer_value);
    command = command << timer_num*2; // Enable the timer
    value = value | command;
    command = command << 1;
    value = value | command; // Select timer
    write_internal_reg(TIMER_COUNTER_CONTROL,value);
}

/** Function Header ***************************************************************************
*** DESCRIPTION:		Disables a counter/timer.
*** WRITTEN BY: 		Tal Gil
*** UPDATED LAST ON: 	11 Mar 1999
*** VERSION: 1.0    ***************************************************************************/

UINT disable_counter_timer(UINT counter_timer_num)
{
    UINT command=1,reg_value;
	UINT value = read_internal_reg(TIMER_COUNTER_CONTROL);
	if ( counter_timer_num > 3 ) return 0xffffffff;
	reg_value = read_internal_reg(TIMER_COUNTER0 + 4*counter_timer_num); 
    command = command << counter_timer_num*2; // Disable the timer/counter
    value = value & (0xffffffff - command);
    write_internal_reg(TIMER_COUNTER_CONTROL,value);
    return reg_value;
}

/** Function Header ***************************************************************************
*** DESCRIPTION:		Reads a counter/timer.
*** WRITTEN BY: 		Tal Gil
*** UPDATED LAST ON: 	11 Mar 1999
*** VERSION: 1.0    ***************************************************************************/

UINT read_counter_timer(UINT counter_timer_num)
{
    if ( counter_timer_num > 3 ) return 0xffffffff;
    return read_internal_reg(TIMER_COUNTER0 + counter_timer_num*4);
}
