/** File Header		***************************************************************************
*** NAME: DMA
*** EXTENSION: H
*** DESCRIPTION: DMA handling functions.
*** WRITTEN BY: Tal Gil
*** UPDATED LAST ON: 11 JAN 1999
*** VERSION: 1.0	***************************************************************************/

#ifndef _DMA_h 
#define _DMA_h

#include "Core.h"

extern UINT GT_INTERNAL_REG_BASE;

#define DECREMENT_SOURCE_ADDRESS	0x00000004
#define HOLD_SOURCE_ADDRESS			0x00000008
#define DECREMENT_DEST_ADDRESS		0x00000010
#define HOLD_DEST_ADDRESS			0x00000020
#define DTL_1BYTE					0x00000140
#define DTL_2BYTES					0x00000180
#define NON_CHAIN_MOD				0x00000200
#define INT_EVERY_NULL_POINTER		0x00000400
#define BLOCK_TRANSFER_MODE			0x00000800
#define CHANNEL_ENABLE				0x00001000
#define FETCH_NEXT_RECORED			0x00002000

#ifdef GT64115 
#define FLY_BY						0x00000001
#define RD_WR_FLY					0x00000002
#define DTL_4BYTES					0x00000000
#define DTL_8BYTES					0x00000040
#define DTL_16BYTES					0x000000c0
#define DTL_32BYTES					0x000001c0
#define ALIGN_TOWARD_DEST			0x00008000
#define MASK_DMA_REQ				0x00010000
#define ENABLE_DESCRIPTOR			0x00020000
#define ENABLE_EOT					0x00040000
#define ENABLE_EOT_INTERRUPT		0x00080000
#define ABORT_DMA					0x00100000
#define SOURCE_ADDR_IN_PCI0			0x00200000
#define SOURCE_ADDR_IN_PCI1			0x00400000
#define DEST_ADDR_IN_PCI0			0x00800000
#define DEST_ADDR_IN_PCI1			0x01000000
#define REC_ADDR_IN_PCI0			0x02000000
#define REC_ADDR_IN_PCI1			0x04000000
#define REQ_FROM_TIMER_COUNTER		0x10000000
#define PLAIN						0x00000880
/* PLAIN = 4 Bytes data transfer limit and Block transfer mode. */
#endif

#if defined(GT64120) || defined(GT64120A) || defined(GT64130) || defined(GT96100) 
#define FLY_BY						0x00000001
#define RD_WR_FLY					0x00000002
#define DTL_4BYTES					0x00000080
#define DTL_8BYTES					0x00000000
#define DTL_16BYTES					0x00000040
#define DTL_32BYTES					0x000000c0
#define DTL_64BYTES					0x000001c0
#define ALIGN_TOWARD_DEST			0x00008000
#define MASK_DMA_REQ				0x00010000
#define ENABLE_DESCRIPTOR			0x00020000
#define ENABLE_EOT					0x00040000
#define ENABLE_EOT_INTERRUPT		0x00080000
#define ABORT_DMA					0x00100000
#define SOURCE_ADDR_IN_PCI0			0x00200000
#define SOURCE_ADDR_IN_PCI1			0x00400000
#define DEST_ADDR_IN_PCI0			0x00800000
#define DEST_ADDR_IN_PCI1			0x01000000
#define REC_ADDR_IN_PCI0			0x02000000
#define REC_ADDR_IN_PCI1			0x04000000
#define REQ_FROM_TIMER_COUNTER		0x10000000
#define PLAIN						0x000009c0
// PLAIN = 64 Bytes data transfer limit and Block transfer mode.
#endif

#ifdef  GT64111
#define SOURCE_ADDR_IN_PCI0			0x00000001
#define DEST_ADDR_IN_PCI0			0x00000002
#define DTL_4BYTES					0x00000000
#define DTL_8BYTES					0x00000040
#define DTL_16BYTES					0x000000c0
#define DTL_32BYTES					0x000001c0
#endif

#define	RETURN_IMMEDIATELY			1
#define WAIT_TO_END					0

typedef struct dma_recored
{
    UINT    ByteCnt;
    UINT    SrcAdd;
    UINT    DestAdd;
    UINT    NextRecPtr;
} DMA_RECORED;


void	perform_dma(UINT channel,UINT source_addr,UINT dest_addr,UINT num_of_bytes,
                    UINT command,Boolean return_flag);
void    perform_cm_dma(UINT channel,UINT source_addr,UINT dest_addr,UINT num_of_bytes,
                       UINT command,Boolean return_flag,DMA_RECORED * next_recored_pointer);
void	dma_command(UINT channel,UINT command);
Boolean is_dma_activ(UINT channel);
Boolean perform_dma_at_slave(UINT channel,UINT source_addr,UINT dest_addr,UINT num_of_words,UINT slot_number,UINT command
							 ,Boolean return_flag);

#endif _DMA_h
