/** File Header		***************************************************************************
*** NAME: 				IO
*** EXTENSION: 			C
*** DESCRIPTION: 		General IO functions.
*** WRITTEN BY: 		Tal Gil
*** UPDATED LAST ON: 	May 11 1999
*** VERSION: 1.0	***************************************************************************/

#include"IO.h"

#define __  255
#define ON  1
#define OFF 0
unsigned int DEBUG_LED_state = OFF;

unsigned char Translation_Table[256] = {
  __, __, __, __, __, __, __, __, __, __, __, __, __, __, __, __,
  __, __, __, __, __, __, __, __, __, __, __, __, __, __, __, __,
  __, __, __, __, __, __, __, __, __, __, __, __, __, __, __, __,
   0,  1,  2,  3,  4,  5,  6,  7,  8,  9, __, __, __, __, __, __,
  __, 10, 11, 12, 13, 14, 15, __, __, __, __, __, __, __, __, __,
  __, __, __, __, __, __, __, __, __, __, __, __, __, __, __, __,
  __, 10, 11, 12, 13, 14, 15, __, __, __, __, __, __, __, __, __,
  __, __, __, __, __, __, __, __, __, __, __, __, __, __, __, __,
  __, __, __, __, __, __, __, __, __, __, __, __, __, __, __, __,
  __, __, __, __, __, __, __, __, __, __, __, __, __, __, __, __,
  __, __, __, __, __, __, __, __, __, __, __, __, __, __, __, __,
  __, __, __, __, __, __, __, __, __, __, __, __, __, __, __, __,
  __, __, __, __, __, __, __, __, __, __, __, __, __, __, __, __,
  __, __, __, __, __, __, __, __, __, __, __, __, __, __, __, __,
  __, __, __, __, __, __, __, __, __, __, __, __, __, __, __, __,
  __, __, __, __, __, __, __, __, __, __, __, __, __, __, __, __,
};
#undef __

/** Function Header ***************************************************************************
*** DESCRIPTION:		Get a string from the user.
*** WRITTEN BY: 		Tal Gil
*** UPDATED LAST ON:	May 11 1999
*** VERSION: 1.0    ***************************************************************************/

void GetStr(char * str)
{
    unsigned char c;
    unsigned int i = 0;
    while((c = getc_direct()) != 13) 
    {
        if(c == '\b') 
        {
            if(i > 0) 
            {
                i--;
                printf("\b \b");
            }
        }
        else 
        {
            str[i++] = c;
            printf("%c",c);
        }
    }
    str[i] = '\0';
}

/** Function Header ***************************************************************************
*** DESCRIPTION:		Convert a string to an unsigned int, on failure it returns 0xffffffff.
*** WRITTEN BY: 		Tal Gil
*** UPDATED LAST ON:	May 11 1999
*** VERSION: 1.0    ***************************************************************************/

unsigned int StrToInt(char * str)
{
    unsigned int num,i=0;
    unsigned char c;
    num = 0;
    if(strlen(str) > 8 ) return 0xffffffff;
    for (i = 0; i < strlen(str); i++) 
    {
        num <<= 4;
        if((c = ascii_to_binary(str[i])) == 255) return 0xffffffff;// Bad hex number

        num |= c;
    }
    return num;
}

/** Function Header ***************************************************************************
*** DESCRIPTION:		Gets a character from the user,if there is no character pending
***                     it waits for it.
*** WRITTEN BY: 		Tal Gil
*** UPDATED LAST ON:	May 11 1999
*** VERSION: 1.0    ***************************************************************************/

unsigned char getc_direct()
{
#if defined(GT64120A) || defined(GT96100)
    unsigned char c,*cp;
    cp = 0xbd000020;
    while(1)
    {
        if(*(cp+0x14) & 0x01) 
        {
            c = (volatile)*cp;
            return c;
        }
        cp++;
        cp--;
    }
#endif
#if defined(GT64115) || defined(GT64115GN)
    unsigned char c,*cp;
    cp = 0xbc000000;;
    while(1)
    {
        if(*(cp+0x8) & 0x01) 
        {
            c = (volatile)*(cp+0xc);
            *(cp+0x8) = 0;
            return c;
        }
        cp++;
        cp--;
    }
#endif
#ifdef GT64120
    unsigned char c,*cp;
    cp = 0xbd000000;
    while(1)
    {
        if(*(cp+0x8) & 0x01) 
        {
            c = (volatile)*(cp+0xc);
            *(cp+0x8) = 0;
            return c;
        }
        cp++;
        cp--;
    }
#endif
}

/** Function Header ***************************************************************************
*** DESCRIPTION:		Sends a character to the console,if the console is busy it waits for it.
*** WRITTEN BY: 		Tal Gil
*** UPDATED LAST ON:	Aug 29 1999
*** VERSION: 1.0    ***************************************************************************/

void putc_direct(unsigned char c)
{
#ifdef GT64115
    while(1)
    {
        if((*(unsigned char*)0xbc000008) & 0x04) 
        {
            *((unsigned char*)0xbc00000c) = c;
            return;
        }
    }
#endif
#if defined(GT64120A) || defined(GT96100)
    char temp;
    do
    {
        temp = *(char*)0xbd000034;
        temp = temp & 0x4;
    }while(!temp);
    *(char*)0xbd000020 = c;
    return;
#endif
#ifdef GT64120
    char temp;
    do
    {
        temp = *(char*)0xbd000008;
        temp = temp & 0x4;
    }while(!temp);
    *(char*)0xbd00000c = c;
    return;
#endif
#ifdef GT64130
    char temp;
    do
    {
        temp = *(char*)0x1d000008;
        temp = temp & 0x4;
    }while(!temp);
    *(char*)0x1d00000c = c;
    return;
#endif
}

/** Function Header ***************************************************************************
*** DESCRIPTION:		Convert a character to binary.
*** WRITTEN BY: 		Tal Gil
*** UPDATED LAST ON:	May 11 1999
*** VERSION: 1.0    ***************************************************************************/

unsigned char ascii_to_binary(unsigned char c)
{
    return Translation_Table[c];
}

/** Function Header ***************************************************************************
*** DESCRIPTION:		Get a character from the user, if there is no character pending it returns 255.
*** WRITTEN BY: 		Tal Gil
*** UPDATED LAST ON:	May 11 1999
*** VERSION: 1.0    ***************************************************************************/

unsigned char read_keyboard()
{
    unsigned char c;
#ifdef  GT64115    
    if((*(unsigned char*)0xbc000008) & 0x01) 
    {
        c = *((unsigned char*)0xbc00000c);
        *(unsigned char*)0xbc000008 = 0;
        return c;
    }
#endif
#if defined(GT64120A) || defined(GT96100)
    char temp;
    temp = *(char*)0xbd000034;
    temp = temp & 0x1;
    if(temp)
    {
        c = *(char*)0xbd000020;
        return c;
    }
#endif
#ifdef GT64120
    char temp;
    temp = *(char*)0xbd000008;
    temp = temp & 0x1;
    if(temp)
    {
        c = *(char*)0xbd00000c;
        return c;
    }
#endif
#ifdef GT64130
    char temp;
    temp = *(char*)0x1d000008;
    temp = temp & 0x1;
    if(temp)
    {
        c = *(char*)0x1d00000c;
        return c;
    }
#endif
    return 255;
}

/** Function Header ***************************************************************************
*** DESCRIPTION:		Perform a warm reset on the CPU.
*** WRITTEN BY: 		Tal Gil
*** UPDATED LAST ON:	May 23 1999
*** VERSION: 1.0    ***************************************************************************/

void perform_soft_reset()
{
#ifdef GT64115
    read_word(0x1d800000);
#endif
#if defined(GT64120A) || defined(GT64130)
    read_word(0x1d180000);
#endif
}

/** Function Header ***************************************************************************
*** DESCRIPTION:		Turns the DEBUG led on.
*** WRITTEN BY: 		Tal Gil
*** UPDATED LAST ON:	May 23 1999
*** VERSION: 1.0    ***************************************************************************/

void debug_led_on()
{
#ifdef GT64115
    if(DEBUG_LED_state == OFF) 
    {
        read_word(0x1d400000);
        DEBUG_LED_state = ON;
    }
#endif
#if defined(GT64120A) || defined(GT64130)    
    if(DEBUG_LED_state == OFF) 
    {
        read_word(0x1d080000);
        DEBUG_LED_state = ON;
    }
#endif
}

/** Function Header ***************************************************************************
*** DESCRIPTION:		Turns the DEBUG led on.
*** WRITTEN BY: 		Tal Gil
*** UPDATED LAST ON:	May 23 1999
*** VERSION: 1.0    ***************************************************************************/

void debug_led_off()
{
#ifdef GT64115
    if(DEBUG_LED_state == ON) 
    {
        read_word(0x1d400000);
        DEBUG_LED_state = OFF;
    }
#endif
#if defined(GT64120A) || defined(GT64130)    
    if(DEBUG_LED_state == ON) 
    {
        read_word(0x1d080000);
        DEBUG_LED_state = OFF;
    }
#endif
}



