/** File Header		***************************************************************************
*** NAME: Stress
*** EXTENSION: C
*** DESCRIPTION: EV96100 board Ethernet test.
*** WRITTEN BY: Erez Yefet
*** UPDATED LAST ON: 12 October 1999
*** VERSION: 1.0    ***************************************************************************/
#define GT96100

#define DATA_TX0 0x310000  // start of Tx buffers
#define DESC_TX0 0xa0300000  // start of Tx descriptors
#define DATA_RX0 0x310000  // start of Rx buffers
#define DESC_RX0 0xa0400000  // start of Rx descriptors

#define UART_NOT_ENTER_HUNT     1<<5
                         
volatile struct SdmaRxDesc *rxdesc[20];
volatile struct SdmaTxDesc *txdesc[20];
volatile struct SdmaRxDesc *temprxdesc;
volatile struct SdmaTxDesc *temptxdesc;



#include "GT96100R.h"
#include "Core.h"
#include "core.c"

#include "mpsc.h"
#include "brg.h"
#include "rout.h"
#include "sdma.h"
#include "set_desc.c"
#include "brg.c"


__main(){}
int main()
{
    uart_init();
    loop();
    return true;
}

/** Function Header	 **************************************************************************
*** NAME: loop
*** EXTENSION: C
*** DESCRIPTION:
***    loop:      
***    When receiving a char MPSC receiver resets owner bit.
***    If owner of receiver(1) =0 then set owner of Tx and enable Tx
***    If owner of Transmitter(1) = 0 then set owner of receiver(1)
***    Jump loop
***
*** WRITTEN BY: Noam Lewis
*** UPDATED LAST ON: MAY 25 2000
*** VERSION: 1.0    ***************************************************************************/
        

int loop()
{
    WAN_SDCM        sdcm0;
    
    temprxdesc=((struct SdmaRxDesc *)(DESC_RX0));
    temptxdesc=((struct SdmaTxDesc *)(DESC_TX0));

    printf("temprxdesc = 0x%x\n",(unsigned int)temprxdesc);

    read_internal(SDCM(GROUP0,0),(UINT*)&sdcm0);   /*enable transmit*/
    sdcm0.txd = 1;

    while(1)
    {
    while(temprxdesc->cmd_sts & OWNER);        /*wait for a char to come from the console*/
    temptxdesc->cmd_sts=temptxdesc->cmd_sts|OWNER;  /*give 96100 ownership over buffer containing received char*/    
    write_internal(SDCM(GROUP0,0),(UINT*)&sdcm0);   /*enable transmit*/
    while(temptxdesc->cmd_sts & OWNER);        /*wait for a char to be transmitted*/
    temprxdesc->cmd_sts=temprxdesc->cmd_sts|OWNER;  /*give 96100 ownership over used buffer - for future chars*/
    temprxdesc=((struct SdmaRxDesc *)(temprxdesc->next_desc_ptr | NONE_CACHEABLE)); /* move reciever to next buffer*/
    temptxdesc=((struct SdmaTxDesc *)(temptxdesc->next_desc_ptr | NONE_CACHEABLE)); /* move trasmitter to next buffer*/
    }
}


/** Function Header	 **************************************************************************
*** NAME: uart_init
*** EXTENSION: C
*** DESCRIPTION: EV96100 board MPSC UART init .
*** WRITTEN BY: Noam Lewis
*** UPDATED LAST ON: MAY 25 2000
*** VERSION: 1.0    ***************************************************************************/

int uart_init()
{
	UINT address,temp,counter,i;

    int loop,error=0;
    UCHAR ch[10];
    UCHAR num;
 
    MPSC_MMCRL      mmcrl0;
    MPSC_MMCRH      mmcrh0;
    UART_PCR        mpcr0;
    UART_CHR1       chr1;
    UART_CHR2       chr2;
    UART_CHR3       chr3;
    UART_CHR4       chr4;
    UART_CHR5       chr5;
    UART_CHR6       chr6;
    UART_CHR7       chr7;
    UART_CHR8       chr8;
    UART_CHR9       chr9;
    MRR_REG         mrr;
    WAN_SDC         sdc0,y;
    WAN_SDCM        sdcm0,x;

    UINT chr10;
    int timeOut;


    printf("MPSC UART mini driver\n");

    write_internal_reg(COMM_UNIT_ARBTR_CONFIG_REG,0x800003ff);
	
    write_internal_reg(MRR,0x00fc0000);                 /* set routing of the 96100 */
                                                    
    write_internal_reg(GPP_CONFIG0,0x00ff0003);
    write_internal_reg(GPP_IO0,0x00660000);            /* config ports a,b as serial ports */
    
    SetRxDesc(DESC_RX0,DATA_RX0);                       /* Initialize Rx descriptors */
    SetTxDesc(DESC_TX0,DATA_TX0);                       /* Initialize Tx descriptors */
    


    error = set_brg(0 , 1 );                            
                                                        /* cdv = 1 for working with 115200 baud rate (rcdv,tcdv = 8) */
                                                        /* 3686400 / ((1+1)*2) = 115200 *8 (rcdv,tcdv = 8) */
    if (error<1) {
        printf("Error in setting BRG\n");
    }
     
    read_internal( BRG_CONFIG(0)  , (UINT*)&temp);
    printf("brg (0x%08x) = %08x \n",BRG_CONFIG(0),temp);        /*verify*/
     
    /* set SDMA regs. */
    
    write_internal_reg(SCRDP(GROUP0,0),(DESC_RX0&0x1fffffff));        
    write_internal_reg(SCTDP(GROUP0,0),(DESC_TX0&0x1fffffff));        
    write_internal_reg(SFTDP(GROUP0,0),(DESC_TX0&0x1fffffff));       

    read_internal(SDC(GROUP0,0)     , (UINT*)&sdc0);
    read_internal(SDCM(GROUP0,0)     , (UINT*)&sdcm0);

    /* set mpsc */
    
    read_internal(MMCRL(0)     , (UINT*)&mmcrl0);
    read_internal(MMCRH(0)     , (UINT*)&mmcrh0);
    read_internal(MPCR(0)      , (UINT*)&mpcr0);
    read_internal(CHR(0,1)     , (UINT*)&chr1);
    read_internal(CHR(0,2)     , (UINT*)&chr2);
    read_internal(CHR(0,3)     , (UINT*)&chr3);
    read_internal(CHR(0,4)     , (UINT*)&chr4);
    read_internal(CHR(0,5)     , (UINT*)&chr5);
    read_internal(CHR(0,6)     , (UINT*)&chr6);
    read_internal(CHR(0,7)     , (UINT*)&chr7);
    read_internal(CHR(0,8)     , (UINT*)&chr8);
    read_internal(CHR(0,9)     , (UINT*)&chr9);

    /* the following is the MPSC init for UART*/

        mmcrl0.gde         = 0;
        mmcrl0.rrvd        = 0;
        mmcrl0.trvd        = 0;
        mmcrl0.crcm        = 0;
        mmcrl0.cdm         = 0;
        mmcrl0.ctsm        = 0;
        mmcrl0.cds         = 0;
        mmcrl0.ctss        = 0;
        mmcrl0.rtsm        = 0;
        mmcrl0.tidl        = 0;
        mmcrl0.tsns        = 0;
        mmcrl0.tysn        = 0;
        mmcrl0.nlm         = 1;
        mmcrl0.lpbk        = 0;
        mmcrl0.et          = 1;
        mmcrl0.er          = 1;
        mmcrl0.trx         = 0;
        mmcrl0.ttx         = 0;
        mmcrl0.mode        = 4;

        write_internal(MMCRL(0),(UINT*)&mmcrl0);

        mmcrh0.gdw         = 0;
        mmcrh0.rcdv        = 1;
        mmcrh0.tcdv        = 1;
        mmcrh0.rdw         = 1;
        mmcrh0.tdec        = 0;
        mmcrh0.renc        = 0;
        mmcrh0.sedg        = 0;
        mmcrh0.rinv        = 0;
        mmcrh0.tinv        = 0;
        mmcrh0.tci         = 0;
        mmcrh0.rysl        = 0;
        mmcrh0.tpl         = 0;
        mmcrh0.tppt        = 0;


        write_internal(MMCRH(0),(UINT*)&mmcrh0);

        
        chr1.brk    =0;
        chr1.tcs    =0xab;

        chr2.tev    =0;
        chr2.tpm    =0;
        chr2.rpm    =0;
        chr2.eh     =1;

        chr3.mir    =0xffff;

        chr4.cfr    =0;

        write_internal(CHR(0,1),(UINT*)&chr1);
        write_internal(CHR(0,2),(UINT*)&chr2);
        write_internal(CHR(0,3),(UINT*)&chr3);
        write_internal(CHR(0,4),(UINT*)&chr4);


        timeOut = 10000;
        read_internal(CHR(0,10),&chr10);
        while(chr10 & UART_NOT_ENTER_HUNT)
        {
            timeOut--;
            read_internal(CHR(0,10),&chr10);
            if(timeOut <= 0)
            {
                printf("ERROR can't enter hunt state\n");
                return false;
            }
        }

        mpcr0.drt   = 0;
        mpcr0.iso   = 0;
        mpcr0.rzs   = 0;
        mpcr0.frz   = 0;
        mpcr0.um    = 0;
        mpcr0.cl    = 3;
        mpcr0.sbl   = 0;
      

        write_internal(MPCR(0),(UINT*)&mpcr0);

        
        read_internal(SDCM(GROUP0,0)     , (UINT*)&sdcm0);
        sdcm0.erd   =1;     /*enable recieve*/

        write_internal(SDCM(GROUP0,0),(UINT*)&sdcm0);


        read_internal(SDCM(GROUP0,0)     , (UINT*)&temp);
        printf("sdcm0 (0x%08x) = %08x \n",SDCM(GROUP0,0),temp);         /*verify*/


        read_internal(SDC(GROUP0,0)     , (UINT*)&temp);
        printf("sdc0 (0x%08x) = %08x \n",SDC(GROUP0,0),temp);         /*verify*/

    return true;
}

